@@ -107,6 +107,13 @@ class QalxJob:
         """shortcut to QalxJob().session"""
         return self.session
 
+    @property
+    def queue(self):
+        """shortcut to the queue instance on the bot entity"""
+        return self.session.queue.get_by_name(
+            self._bot_entity.config.queue_name
+        )
+
     def stop_processing(self):
         """
         Stop the worker from processing.  Will cause the worker to wait until
@@ -218,11 +225,11 @@ class QalxJob:
             raise TypeError(
                 "Method add_item_data only works on jobs with a set entity."
             )
-        self.entity["items"][item_key] = self.session.item.add(
+        self.entity.items_[item_key] = self.session.item.add(
             data=data, meta=meta
         )
         self.save_entity()
-        return self.entity["items"][item_key]
+        return self.entity.items_[item_key]
 
     def save_entity(self):
         """
@@ -451,7 +458,7 @@ class Bot:
 
         # Update the token on the bot_session to ensure all subsequent
         # requests use the token from the bot
-        token = self.bot_entity["info"]["credentials"]["token"]
+        token = self.bot_entity.info.credentials.token
         bot_session.rest_api.token = token
 
         self.bot_entity = self.bot_adapter.replace_workers(
@@ -470,7 +477,7 @@ class Bot:
                     steps,
                     queue,
                     self.bot_entity,
-                    self.bot_entity["workers"][worker],
+                    self.bot_entity.workers[worker],
                     worker_adapter,
                     index=worker,
                     workflow=self.workflow,
@@ -633,7 +640,7 @@ class Worker(Process):
         directory = self.config["WORKER_LOG_FILE_DIR"]
         level = self.config["LOGGING_LEVEL"]
         filename = os.path.join(
-            directory, f'.worker_{self.bot_entity["name"]}.{self.index}.log'
+            directory, f".worker_{self.bot_entity.name}.{self.index}.log"
         )
         self.log = configure_logging(f"worker.{self.index}", filename, level)
 
@@ -647,13 +654,28 @@ class Worker(Process):
 
     def _check_worker_signal(self):
         """
-        Reload the worker signal and either terminates the worker or stops it
+        Reload the worker signal and either terminates the worker or sets the
+        stop flag so that the worker can stop processing the next time
+        `self._continue_processing` is checked
         """
+        # The first time the bot starts the signal won't be set yet unless the
+        # bot itself was started with `stop=True` (i.e. when building factories)
+        stopped_status = getattr(self.worker_signal, "stop", False)
+
+        # Once we've reloaded the signal we can decide what needs to be done
+        # with the bot
         self._reload_signal()
 
         if self.worker_signal.terminate_warm:
             self._do_exit(**QalxSignal._warm_exit_update())
         else:
+            if self.worker_signal.stop != stopped_status:
+                # The worker stop signal has changed state - log it so the user
+                # knows what's going on
+                update = QalxSignal._stop_or_resume_update(
+                    stop=self.worker_signal.stop
+                )
+                self.log.info(f'[{update["code"]}] {update["update"]}')
             self.stop = self.worker_signal.stop
 
     def _do_exit(self, update, code=QalxSignal.BASE_EXIT_CODE):
@@ -662,6 +684,7 @@ class Worker(Process):
         if onterm:
             onterm(self.job)
         self.job.publish_status(update)
+        self.log.info(f"[{code}] {update}")
         sys.exit(code)
 
     def _check_cold_exit(self, reload_signal=True):
@@ -788,7 +811,7 @@ class Worker(Process):
         if self.queue._credentials_expiring_soon():
             self.log.debug(
                 f"refreshing security credentials for queue "
-                f'`{self.queue["name"]}`'
+                f"`{self.queue.name}`"
             )
             self.queue = self.queue_adapter.reload(self.queue)
 
@@ -849,7 +872,7 @@ class Worker(Process):
                     no_message_attempts += 1
 
             if (kill_after is not None) and (no_message_attempts >= kill_after):
-                self._do_exit("KILL_AFTER reached", 72593)
+                self._do_exit(**QalxSignal._config_exit_update())
 
     def _process_functions(self):
         def process_as_far_as_possible(functions):
@@ -869,7 +892,7 @@ class Worker(Process):
                             exc_value=exc_value,
                             exc_traceback=exc_traceback,
                             extra={
-                                "entity_guid": self.job.entity["guid"],
+                                "entity_guid": self.job.entity.guid,
                                 "entity_type": self.job.entity.entity_type,
                             },
                             log=self.log,
