@@ -56,4 +56,12 @@ Defaults to the following:
 * Mac: ~/Library/Application Support/qalx
 """
 
+REGION = "eu-west-2"
+r"""
+The region that will be used when connecting to databases or other remote
+services.  Originally set via `qalx configure`.  Change this to another valid
+region to use services in that region.
+This is only a valid option for User configs - not for Bot configs
+"""
+
 del APPNAME, APPAUTHOR  # These are not config keys
