@@ -10,6 +10,8 @@ class QalxSignal(object):
     TERMINATE_WARM_CODE = 72591
     TERMINATE_COLD_CODE = 72592
     CONFIG_TERMINATE_CODE = 72593
+    RESUME_CODE = 72594
+    STOP_CODE = 72595
     COLD_EXIT_KEY = "cold"
     WARM_EXIT_KEY = "warm"
     REQUEUE_JOB_KEY = "requeue_job"
@@ -61,6 +63,19 @@ class QalxSignal(object):
             f"{cls.COLD_EXIT_KEY} exit signal found", cls.TERMINATE_COLD_CODE
         )
 
+    @classmethod
+    def _config_exit_update(cls):
+        return cls._build_update(
+            "KILL_AFTER reached", cls.CONFIG_TERMINATE_CODE
+        )
+
+    @classmethod
+    def _stop_or_resume_update(cls, stop):
+        return cls._build_update(
+            f"{'stop' if stop else 'resume'} signal found",
+            cls.STOP_CODE if stop else cls.RESUME_CODE,
+        )
+
     @property
     def terminate(self):
         """
